==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PL/ts/Arc2PL_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Arc2PL</name>
    <message>
        <location filename="../Arc2PL.js" line="+65"/>
        <source>Start point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>The distance between the two points must be less than the arc length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PL.ui" line="+17"/>
        <source>Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PLInit.js" line="+2"/>
        <source>&amp;2 Points and Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PL/ts/Arc2PL_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Arc2PL</name>
    <message>
        <location filename="../Arc2PL.js" line="+65"/>
        <source>Start point</source>
        <translation>起点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>终点</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid length</source>
        <translation>无效长度</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>两点为同一点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>The distance between the two points must be less than the arc length</source>
        <translation>两点间的长度必须小于弧长</translation>
    </message>
    <message>
        <location filename="../Arc2PL.ui" line="+17"/>
        <source>Length:</source>
        <translation>长度：</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>方向：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>逆时针（正向）</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation>顺时针（负向）</translation>
    </message>
    <message>
        <location filename="../Arc2PLInit.js" line="+2"/>
        <source>&amp;2 Points and Length</source>
        <translation>两点和长度(&amp;2)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and length</source>
        <translation>以两点和长度画弧</translation>
    </message>
</context>
</TS>
